@@ -1,12 +1,11 @@
 ##### Render LAMMPS regions #####
 #
-# Generates a mesh representation from [LAMMPS region](https://docs.lammps.org/region.html) commands.
+# Generates a mesh representation from LAMMPS *region* commands.
+# [See documentation...](manual:modifiers.render_lammps_regions)
 #
 # Supported styles: *block*, *cone*, *cylinder*, *ellipsoid*, *plane*, *prism*, *sphere*.
 #
 # Supported keywords: *rotate*, *move*, *side*, *open*.
-#
-# [See documentation](manual:modifiers.render_lammps_regions)
 
 import ovito
 from ovito.data import *
@@ -801,9 +800,9 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
         else:
              surface_mesh = data.surfaces['lammps-regions']
         if 'Region ID' not in surface_mesh.regions:
-            surface_mesh.regions_.create_property('Region ID', data = [], components = 1, dtype=int)
+            surface_mesh.regions_.create_property('Region ID', components=1, dtype=int)
         if "Region" not in surface_mesh.faces:
-            surface_mesh.faces_.create_property('Region', data = [])
+            surface_mesh.faces_.create_property('Region')
 
         region_color_map = iter([(0.828, 0.864, 0.514), (0.575, 0.239, 0.359), (0.112, 0.277, 0.496), (0.228, 0.104, 0.517), (0.058, 0.512, 0.376), (0.131, 0.769, 0.753)])
 
@@ -814,7 +813,7 @@ class RenderLAMMPSRegionsModifier(ModifierInterface):
             region = self.parse_region_command(str(command))
             region.generate_mesh(surface_mesh, color = next(region_color_map))
             if self.select_atoms:
-                np.logical_or(sel, region.is_inside(data.particles.positions), out = sel[...])
+                np.logical_or(sel, region.is_inside(data.particles.positions), out=sel[...])
         surface_mesh.connect_opposite_halfedges()
 
         # Color mesh faces by region type
